@@ -53,8 +53,10 @@ set debug false
 ##
 
 proc reset {} {
-    catch {
-	unset nodes networks links ids trace mask fip name address gateways
+    foreach name {
+	nodes networks links ids trace mask fip name address gateways
+    } {
+	catch {unset $name}
     }
 }
 
@@ -147,7 +149,7 @@ proc newid {} {
 
 proc netping { network } {
     set result ""
-    if {[regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $network] > 0} {
+    if {[regexp {^[0-9]+\.[0-9]+\.[0-9]+$} $network] > 0} {
 	set hosts ""
 	for {set a4 1} {$a4<255} {incr a4} {
 	    append hosts " $network.$a4"
@@ -173,7 +175,7 @@ proc netping { network } {
 ##
 
 proc discover_nodes {network} {
-    if {[regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $network] > 0} {
+    if {[regexp {^[0-9]+\.[0-9]+\.[0-9]+$} $network] > 0} {
 	set count 0
 	set start [clock seconds]
 	foreach ip [netping $network] {
@@ -183,12 +185,12 @@ proc discover_nodes {network} {
 	writeln "$count nodes found on network $network in [expr {[clock seconds]-$start}] seconds."
 	flush stdout
     }
-    if {[regexp "^\[0-9\]+\.\[0-9\]+$" $network] > 0} {
+    if {[regexp {^[0-9]+\.[0-9]+$} $network] > 0} {
 	for {set a3 0} {$a3<256} {incr a3} {
 	    discover_nodes $network.$a3
 	}
     }
-    if {[regexp "^\[0-9\]+$" $network] > 0} {
+    if {[regexp {^[0-9]+$} $network] > 0} {
 	for {set a2 0} {$a2<256} {incr a2} {
 	    discover_nodes $network.$a2
 	}
@@ -671,7 +673,7 @@ proc discover_gateways {} {
 	if {$len > 1} {
 	    foreach hop [lrange $trace($id) 0 [incr len -2]] {
 		if {[info exists table($hop)]} continue
-		if {[regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $hop]} {
+		if {[regexp {^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$} $hop]} {
 		    set gate_id $ids($hop)
 		    set gateways($gate_id) $hop
 		}
@@ -1179,8 +1181,7 @@ proc "Discover IP Network" {list} {
 	discover_links
 	merge_gateways
 	talk_to_ined
-	unset nodes networks links ids trace mask fip name address
-	catch {unset gateways}
+	reset
     }
 
     writeln "Discover finished in [expr {[clock seconds]-$start}] seconds"
@@ -1227,7 +1228,7 @@ proc "Discover Route" {list} {
 	if {[lsearch $new_ips $ip] >= 0} continue
 	lappend new_ips $ip
 
-	if {![regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $ip]} {
+	if {![regexp {^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$} $ip]} {
 	    set host $ip
 	    if {[catch {nslook $host} ip]} {
 		ined acknowledge "Can not lookup IP address for $host."
@@ -1257,9 +1258,11 @@ proc "Discover Route" {list} {
 	discover_links
 	merge_gateways
 	talk_to_ined
-	unset nodes networks links ids trace mask fip name address
-	catch {unset gateways}
-	
+	foreach name {
+	    nodes networks links ids trace mask fip name address gateways
+	} {
+	    catch {unset $name}
+	}
     }
 
     writeln "discover finished in [expr {[clock seconds]-$start}] seconds"
@@ -1433,8 +1436,7 @@ proc ined_create {host user} {
 	    discover_links
 	    merge_gateways
 	    talk_to_ined
-	    unset nodes networks links ids trace mask fip name address
-	    catch {unset gateways}
+	    reset
 	}
 	
 	writeln "discover finished in [expr {[clock seconds]-$start}] seconds"
