@@ -123,7 +123,7 @@ proc "Set Address" { list } {
 		}
 		continue
 	    }
-	    if {[regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $host]} {
+	    if {[regexp {^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$} $host]} {
 		ined -noupdate address $id $host
 		ined label $id address
 		continue
