@@ -22,7 +22,7 @@ IpInit IP-Trouble
 ##
 
 proc netping {network} {
-    if {[regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $network]>0} {
+    if {[regexp {^[0-9]+\.[0-9]+\.[0-9]+$} $network]>0} {
 	set hosts ""
 	for {set a4 1} {$a4<255} {incr a4} {
 	    lappend hosts $network.$a4
@@ -32,7 +32,7 @@ proc netping {network} {
 	}
 	return $res
     }
-    if {[regexp "^\[0-9\]+\.\[0-9\]+$" $network]>0} {
+    if {[regexp {^[0-9]+\.[0-9]+$} $network]>0} {
 	set result ""
 	for {set a3 0} {$a3<256} {incr a3} {
 	    lappend result [netping $network.$a3]
@@ -86,7 +86,7 @@ proc Ping {list} {
 	foreach comp $networks {
 	    set net [ined name $comp]
 	    set ip [ined address $comp]
-	    if {![regexp "^\[0-9\]+\.\[0-9\]+\.\[0-9\]+$" $ip]} {
+	    if {![regexp {^[0-9]+\.[0-9]+\.[0-9]+$} $ip]} {
 		ined acknowledge "Can not lookup IP Address for $net."
 		continue
 	    }
