@@ -115,6 +115,7 @@ proc ShowVariableProc {id status vbl} {
     switch -glob $syntax {
 	Gauge -
 	INTEGER -
+	Unsigned32 -
 	Integer32 {
 	    set val $value
 	}
@@ -148,7 +149,7 @@ proc ShowVariable { ids } {
 ## list contains node ids with the snmp variable oid to display.
 ##
 
-proc start_snmp_monitor { ip args } {
+proc start_snmp_monitor { ip uptime args } {
     global cx interval
 
     set ids ""
@@ -160,7 +161,7 @@ proc start_snmp_monitor { ip args } {
 
 	if {$id != ""} {
 	    set s [SnmpOpen $id $ip]
-	    if {[catch {$s get "sysUpTime.0 $var"} vbl]} {
+	    if {[catch {$s get [list $uptime $var]} vbl]} {
 		set name [ined -noupdate name $id]
 		set addr [ined -noupdate address $id]
 		set msg "Unable to restart monitor job on $name"
@@ -191,7 +192,7 @@ proc start_snmp_monitor { ip args } {
     if {$ids != ""} {
 	set jid [job create -command [list ShowVariable $ids] \
 		 -interval [expr $interval * 1000]]
-	save "restart start_snmp_monitor $interval $jid $ip $re_args"
+	save "restart start_snmp_monitor $interval $jid $ip $uptime $re_args"
     }
 }
 
@@ -201,11 +202,21 @@ proc start_snmp_monitor { ip args } {
 ## must be done very carefully...
 ##
 
-proc MonitorVariable {list varname} {
+proc MonitorVariable {list uptime varname} {
     ForeachIpNode id ip host $list {
 	set s [SnmpOpen $id $ip]
-	set syntaxList "Gauge Counter Counter32 Counter64 INTEGER"
+	set syntaxList {
+	    Gauge Gauge32 Counter Counter32 Counter64 
+	    Unsigned32 INTEGER Integer32
+	}
 	set vars ""
+
+	set err [catch {$s get $uptime} vbl]
+	if {$err || [lindex [lindex $vbl 0] 1] == "noSuchInstance"} {
+	    ined acknowledge "Time base problem on $ip: $vbl"
+	    $s destroy
+	    return ""
+	}
 	
 	set err [catch {$s get $varname} vbl]
 	if {$err || [lindex [lindex $vbl 0] 1] == "noSuchInstance"} {
@@ -214,6 +225,9 @@ proc MonitorVariable {list varname} {
 		    set syntax [lindex [lindex $vbl 0] 1]
 		    if {[lsearch $syntaxList $syntax] >= 0} {
 			lappend vars [lindex [lindex $vbl 0] 0]
+		    } else {
+			set name [mib name [lindex [lindex $vbl 0] 0]]
+			writeln "$host: $name of base type $syntax ignored"
 		    }
 		}
 	    } msg]} {
@@ -225,9 +239,12 @@ proc MonitorVariable {list varname} {
 	    set syntax [lindex [lindex $vbl 0] 1]
 	    if {[lsearch $syntaxList $syntax] >= 0} {
 		lappend vars [lindex [lindex $vbl 0] 0]
+	    } else {
+		set name [mib name [lindex [lindex $vbl 0] 0]]
+		writeln "$host: $name of base type $syntax ignored"
 	    }
 	}
-	
+
 	if {$vars == ""} {
 	    ined acknowledge \
 		    "$varname is either not available or of wrong type."
@@ -235,6 +252,7 @@ proc MonitorVariable {list varname} {
 	}
 	
 	set args $ip
+	lappend args $uptime
 	set i 0
 	foreach var $vars {
 	    set nid [CreateChart $id [expr 30+$i] [expr 30+$i]]
@@ -256,17 +274,32 @@ proc MonitorVariable {list varname} {
 
 proc "Monitor Variable" { list } {
 
-    static varname
+    static varname uptime
 
     if {![info exists varname]} {
 	set varname ip.ipForwDatagrams
     }
+    if {![info exists uptime]} {
+	set uptime system.sysUpTime.0
+    }
 
-    set res [ined request "Tell me which variables I should show you:" \
-	    [list [list "SNMP Variables:" $varname] ] \
+    set res [ined request "Fill in the SNMP variables to be monitored:" \
+	    [list [list "Variables:" $varname] \
+	          [list "Time base:" $uptime] ] \
 	    [list start cancel] ]
     if {[lindex $res 0] == "cancel"} return
-    
+
+    set var [lindex $res 2]
+    if {[catch {mib oid $var}]} {
+	ined acknowledge "Unknown SNMP variable \"$var\"."
+	return
+    }
+    if {[mib syntax $var] != "TimeTicks"} {
+	ined acknowledge "Time base variable not of type TimeTicks."
+	return
+    }
+    set uptime $var
+
     set varname ""
     foreach var [lindex $res 1] {
 	if {[catch {mib oid $var}]} {
@@ -277,7 +310,7 @@ proc "Monitor Variable" { list } {
     }
 
     foreach var $varname {
-	MonitorVariable $list $var
+	MonitorVariable $list $uptime $var
     }
 }
 
