@@ -19,6 +19,8 @@ static int force = 0;                    /* force a full dump */
 static int numEditors = 0;               /* the number of editor objects */
 static char *defaultName = "noname.tki"; /* the default map name */
 
+#define TKI_PAGE_RESOLUTION 5
+
 /*
  * Forward declarations for procedures defined later in this file:
  */
@@ -40,6 +42,18 @@ static int
 GetId		_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
 			     int argc, char **argv));
 static int
+GetWidth	_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
+			     int argc, char **argv));
+static int
+GetHeight	_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
+			     int argc, char **argv));
+static int
+GetPageWidth	_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
+			     int argc, char **argv));
+static int
+GetPageHeight	_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
+			     int argc, char **argv));
+static int
 Toplevel	_ANSI_ARGS_((Tki_Editor *editor, Tcl_Interp *interp, 
 			     int argc, char **argv));
 static int
@@ -125,6 +139,7 @@ Tki_CreateEditor (clientData, interp, argc, argv)
     editor->pagesize = ckstrdup("");
     editor->landscape = 0;
     editor->width = 0; editor->height = 0;
+    editor->pagewidth = 0; editor->pageheight = 0;
 
     editor->traceCount = 0;
 
@@ -446,6 +461,66 @@ GetColor (editor, interp, argc, argv)
     return TCL_OK;
 }
 
+/*
+ * Get the current width of the drawing area.
+ */
+
+static int
+GetWidth (editor, interp, argc, argv)
+    Tcl_Interp *interp;
+    Tki_Editor *editor;
+    int argc;
+    char **argv;
+{
+    sprintf (interp->result, "%d", editor->width);
+    return TCL_OK;
+}
+
+/*
+ * Get the current height of the drawing area.
+ */
+
+static int
+GetHeight (editor, interp, argc, argv)
+    Tcl_Interp *interp;
+    Tki_Editor *editor;
+    int argc;
+    char **argv;
+{
+    sprintf (interp->result, "%d", editor->height);
+    return TCL_OK;
+}
+
+/*
+ * Get the current width of the printed page in millimeter.
+ */
+
+static int
+GetPageWidth (editor, interp, argc, argv)
+    Tcl_Interp *interp;
+    Tki_Editor *editor;
+    int argc;
+    char **argv;
+{
+    sprintf (interp->result, "%d", editor->pagewidth);
+    return TCL_OK;
+}
+
+/*
+ * Get the current height of the printed page in millimeter.
+ */
+
+static int
+GetPageHeight (editor, interp, argc, argv)
+    Tcl_Interp *interp;
+    Tki_Editor *editor;
+    int argc;
+    char **argv;
+{
+    sprintf (interp->result, "%d", editor->pageheight);
+    return TCL_OK;
+}
+
 /*
  * Get or set the current directory name.
  */
@@ -498,61 +573,48 @@ Tki_EditorPageSize (editor, interp, argc, argv)
     int argc;
     char **argv;
 {
+    typedef struct PageSize {
+	char *name;
+	int width;
+	int height;
+    } PageSize;
+
+    PageSize pageSizeTable[] = {
+	{ "A4",		210,	 297 },
+	{ "A3",		297,	 420 },
+	{ "A2",		420,	 594 },
+	{ "A1",		594,	 841 },
+	{ "A0",		841,	1189 },
+	{ "Letter",	216,	 279 },
+	{ "Legal",	216,	 356 },
+	{ NULL,		  0,	   0 },
+    };
+    
     if (argc == 1) {
 
-	if (strcmp (argv[0], "Letter") == 0) {
-	    STRCOPY (editor->pagesize, "Letter");
-	    editor->width  = 216;
-	    editor->height = 279;
-	} else if (strcmp (argv[0], "Legal") == 0) {
-	    STRCOPY (editor->pagesize, "Legal");
-            editor->width  = 216;
-            editor->height = 356;
-	} else if (strcmp (argv[0], "DINA3") == 0
-		   || strcmp (argv[0], "A3") == 0) {
-	    STRCOPY (editor->pagesize, "A3");
-	    editor->width  = 297;
-	    editor->height = 420;
-	} else if (strcmp (argv[0], "DINA2") == 0
-		   || strcmp (argv[0], "A2") == 0) {
-	    STRCOPY (editor->pagesize, "A2");
-	    editor->width  = 420;
-	    editor->height = 595;
-	} else if (strcmp (argv[0], "DINA1") == 0
-		   || strcmp (argv[0], "A1") == 0) {
-	    STRCOPY (editor->pagesize, "A1");
-	    editor->width  = 595;
-	    editor->height = 841;
-        } else if (strcmp (argv[0], "DINA0") == 0
-                   || strcmp (argv[0], "A0") == 0) {
-            STRCOPY (editor->pagesize, "A0");
-            editor->width  = 841;
-            editor->height = 1189;
-	} else {
-	    STRCOPY (editor->pagesize, "A4");
-	    editor->width  = 210;
-	    editor->height = 297;
+	PageSize *p;
+
+	for (p = pageSizeTable; p->name; p++) {
+	    if (0 == strcmp(argv[0], p->name)) break;
 	}
-	
+	if (! p->name) {		/* use first entry as default */
+	    p = pageSizeTable;
+	}
+
+	STRCOPY(editor->pagesize, p->name);
+	editor->pagewidth  = p->width;
+	editor->pageheight = p->height;
+
 	/* Flip the page if we should use landscape orientation. */
 	if (editor->landscape) {
-	    int tmp = editor->width;
-	    editor->width = editor->height;
-	    editor->height = tmp;
-	}
-
-	/* Convert millimeters in canvas pixels */
-	sprintf (buffer, "winfo pixels %s %dm", 
-		 editor->toplevel, editor->width);
-	if (Tcl_Eval(interp, buffer) == TCL_OK) {
-	    Tcl_GetInt (interp, interp->result, &editor->width);
-	}
-	sprintf (buffer, "winfo pixels %s %dm", 
-		 editor->toplevel, editor->height);
-	if (Tcl_Eval(interp, buffer) == TCL_OK) {
-	    Tcl_GetInt (interp, interp->result, &editor->height);
+	    int tmp = editor->pagewidth;
+	    editor->pagewidth = editor->pageheight;
+	    editor->pageheight = tmp;
 	}
 
+	editor->width = editor->pagewidth * TKI_PAGE_RESOLUTION;
+	editor->height = editor->pageheight * TKI_PAGE_RESOLUTION;
+	
 	sprintf (buffer, "Editor__pagesize %s %d %d",
 		 editor->id, editor->width, editor->height);
 	Tcl_Eval (interp, buffer);
@@ -578,21 +640,25 @@ Tki_EditorOrientation (editor, interp, argc, argv)
     if (argc == 1) {
 	if (strcmp(argv[0], "portrait") == 0) {
 	    if (editor->landscape) {
-		int tmp = editor->width;
-		editor->width = editor->height;
-		editor->height = tmp;
+		int tmp = editor->pagewidth;
+		editor->pagewidth = editor->pageheight;
+		editor->pageheight = tmp;
 	    }
 	    editor->landscape = 0;
+	    editor->width = editor->pagewidth * TKI_PAGE_RESOLUTION;
+	    editor->height = editor->pageheight * TKI_PAGE_RESOLUTION;
 	    sprintf (buffer, "Editor__pagesize %s %d %d",
 		     editor->id, editor->width, editor->height);
 	    Tcl_Eval (interp, buffer);
 	} else {
 	    if (! editor->landscape) {
-		int tmp = editor->width;
-                editor->width = editor->height;
-                editor->height = tmp;
+		int tmp = editor->pagewidth;
+                editor->pagewidth = editor->pageheight;
+                editor->pageheight = tmp;
 	    }
 	    editor->landscape = 1;
+	    editor->width = editor->pagewidth * TKI_PAGE_RESOLUTION;
+	    editor->height = editor->pageheight * TKI_PAGE_RESOLUTION;
 	    sprintf (buffer, "Editor__pagesize %s %d %d",
 		     editor->id, editor->width, editor->height);
 	    Tcl_Eval (interp, buffer);
@@ -1551,6 +1617,10 @@ static Method methodTable[] = {
 	{ "selection",   Tki_EditorSelection },
 
 	{ "color",	 GetColor },
+	{ "width",	 GetWidth },
+	{ "height",	 GetHeight },
+	{ "pagewidth",	 GetPageWidth },
+	{ "pageheight",	 GetPageHeight },
 
 	{ "dirname",     DirName },
 	{ "filename",    FileName },
