@@ -1118,6 +1118,8 @@ m_interpreter_create (interp, object, argc, argv)
     recvData->interp = interp;
     recvData->object = object;
 
+    Tcl_RegisterChannel((Tcl_Interp *) NULL, object->channel);
+
     Tcl_CreateChannelHandler(object->channel, TCL_READABLE, 
 			     receive, (ClientData) recvData);
 
@@ -4117,7 +4119,7 @@ m_flash (interp, object, argc, argv)
 		                   secs : anObject->flash;
 	    } else {
 	        anObject->flash = secs;
-		flash (interp, anObject);
+		TkiFlash (interp, anObject);
 	    }
 	
 	    if (*anObject->canvas == '\0') {
