@@ -351,7 +351,8 @@ Tki_DeleteObject (clientData)
     
     if (object->type == TKINED_INTERPRETER) {
 
-	Tcl_Close((Tcl_Interp *) NULL, object->channel);
+	Tcl_UnregisterChannel((Tcl_Interp *) NULL, object->channel);
+	/* Tcl_Close((Tcl_Interp *) NULL, object->channel); */
 
 	if (object->cmd) {
 	    Tcl_DStringFree (object->cmd);
