@@ -671,9 +671,9 @@ HttpGeneralHeader(channel)
     time_t clock = time(0);
     struct tm *tm = gmtime(&clock);
 
-    sprintf(buffer, "Date: %s, %2d %s 19%2d %02d:%02d:%02d\n",
+    sprintf(buffer, "Date: %s, %2d %s %d %02d:%02d:%02d\n",
 	    weekdays[tm->tm_wday], tm->tm_mday, 
-	    months[tm->tm_mon], tm->tm_year,
+	    months[tm->tm_mon], 1900 + tm->tm_year,
 	    tm->tm_hour, tm->tm_min, tm->tm_sec);
     Tcl_Write(channel, buffer, strlen(buffer));
     Tcl_Write(channel, "MIME-Version: 1.0\n", 18);
