@@ -234,11 +234,12 @@ InedFatal(interp)
     Tcl_Interp *interp;
 {
     Tcl_Channel channel;
-    char *msg = "Tnm lost connection to Tkined\n";
 
     channel = Tcl_GetChannel(interp, "stderr", NULL);
     if (channel) {
-	Tcl_Write(channel, msg, strlen(msg));
+	Tcl_Write(channel, "Tnm lost connection to Tkined (", -1);
+	Tcl_Write(channel, Tcl_PosixError(interp), -1);
+	Tcl_Write(channel, ")\n", -1);
 	Tcl_Flush(channel);
     }
     Tcl_Exit(1);
@@ -622,6 +623,7 @@ Tnm_InedCmd(clientData, interp, argc, argv)
 
     for (i = 0; i < argc; i++) {
 	if (Tcl_Write(channel, "{", 1) < 0) InedFatal(interp);
+
         for (p = argv[i]; *p; p++) {
 	    if (*p == '\r') {
 		continue;
