@@ -373,6 +373,15 @@ AdjustTime(control)
 
     control->lastTime = currentTime;
 
+    /*
+     * Do not increase remaining times of any jobs if the clock
+     * has moved backwards.
+     */
+
+    if (delta <= 0) {
+	return;
+    }
+
     for (jobPtr = control->jobList; jobPtr; jobPtr = jobPtr->nextPtr) {
         if (jobPtr->status != TNM_JOB_SUSPEND) {
 	    jobPtr->remtime -= delta;
