@@ -84,9 +84,8 @@ NetdbHosts(interp, argc, argv)
     if (argc == 2) {
 #ifdef HAVE_GETHOSTENT
 	struct hostent *host;
-	unsigned long addr;
 	struct in_addr *paddr;
-	char buffer[20];
+	struct in_addr ipaddr;
 	int i = 0;
 	
 	sethostent(0);
@@ -95,11 +94,9 @@ NetdbHosts(interp, argc, argv)
 			     (char *) NULL);
 	    if (*host->h_addr_list) {
 		paddr = (struct in_addr *) *host->h_addr_list++;
-		addr = ntohl(paddr->s_addr);
-		sprintf(buffer, "%lu.%lu.%lu.%lu",
-			(addr >> 24) & 0xff, (addr >> 16) & 0xff,
-			(addr >> 8) & 0xff, addr & 0xff);
-		Tcl_AppendResult(interp, " ", buffer, "}", (char *) NULL);
+		ipaddr.s_addr = ntohl(paddr->s_addr);
+		Tcl_AppendResult(interp, " ", inet_ntoa(ipaddr), "}",
+				 (char *) NULL);
 	    }
 	}
 	endhostent();
@@ -182,6 +179,8 @@ NetdbIp(interp, argc, argv)
     int argc;
     char **argv;
 {
+    struct in_addr ipaddr;
+    
     if (argc == 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
 			 " ip option arg\"", (char *) NULL);
@@ -233,7 +232,6 @@ NetdbIp(interp, argc, argv)
 
     if (strcmp(argv[2], "range") == 0) {
 	unsigned long net, mask, addr;
-	char buf[20];
 	if (argc != 5) {
 	    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
 			     " ip range address mask\"", (char *) NULL);
@@ -259,10 +257,8 @@ NetdbIp(interp, argc, argv)
 	mask = ntohl(mask);
     
 	for (addr = net + 1; addr < net + ~mask; addr++) {
-	    sprintf(buf, "%lu.%lu.%lu.%lu",
-		    (addr >> 24) & 0xff, (addr >> 16) & 0xff,
-		    (addr >> 8) & 0xff, addr & 0xff);
-	    Tcl_AppendElement(interp, buf);
+	    ipaddr.s_addr = addr;
+	    Tcl_AppendElement(interp, inet_ntoa(ipaddr));
 	}
 	return TCL_OK;
     }
@@ -302,7 +298,7 @@ NetdbNetworks(interp, argc, argv)
     if (argc == 2) {
 #ifdef HAVE_GETNETENT
 	struct netent *net;
-	char buf[20];
+	struct in_addr ipaddr;
 	int i = 0;
 	
 	setnetent(0);
@@ -310,11 +306,9 @@ NetdbNetworks(interp, argc, argv)
 	    while (net->n_net && ! ((net->n_net >> 24) & 0xff)) {
 		net->n_net <<= 8;
 	    }
-	    sprintf(buf, "%lu.%lu.%lu.%lu",
-		    (net->n_net >> 24) & 0xff, (net->n_net >> 16) & 0xff,
-		    (net->n_net >> 8) & 0xff, net->n_net & 0xff);
+	    ipaddr.s_addr = htonl(net->n_net);
 	    Tcl_AppendResult(interp, i++ ? " {" : "{", net->n_name, 
-			     " ", buf, "}", (char *) NULL);
+			     " ", inet_ntoa(ipaddr), "}", (char *) NULL);
 	}
 	endnetent();
 #endif
@@ -359,6 +353,8 @@ NetdbNetworks(interp, argc, argv)
 
     if (strcmp(argv[2], "address") == 0) {
 	struct netent *net;
+	struct in_addr ipaddr;
+	
 	if (argc != 4) {
 	    Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
 			     " networks address name\"", (char *) NULL);
@@ -372,9 +368,8 @@ NetdbNetworks(interp, argc, argv)
 	while (net->n_net && ! ((net->n_net >> 24) & 0xff)) {
 	    net->n_net <<= 8;
 	}
-	sprintf(interp->result, "%lu.%lu.%lu.%lu",
-		(net->n_net >> 24) & 0xff, (net->n_net >> 16) & 0xff,
-		(net->n_net >> 8) & 0xff, net->n_net & 0xff);
+	ipaddr.s_addr = net->n_net;
+	Tcl_SetResult(interp, inet_ntoa(ipaddr), TCL_VOLATILE);
 	return TCL_OK;
     }
 
