@@ -643,7 +643,7 @@ UdpMulticast(interp, argc, argv)
 	}
 
 	mreq.imr_multiaddr.s_addr = name.sin_addr.s_addr;
-	name.sin_addr.s_addr = htonl(INADDR_ANY);
+	name.imr_interface.s_addr = htonl(INADDR_ANY);
 
 	sock = TnmSocket(PF_INET, SOCK_DGRAM, 0);
 	if (sock == TNM_SOCKET_ERROR) {
