@@ -438,12 +438,13 @@ TnmSetIPAddress(interp, host, addr)
     }
 
     /*
-     * Convert the IP address into the internal format.
+     * Convert the IP address into the internal format. Note that
+     * inet_addr can't handle the valid address 255.255.255.255.
      */
 
     if (type == TNM_IP_HOST_ADDRESS) {
 	int hostaddr = inet_addr(host);
-	if (hostaddr == -1) {
+	if (hostaddr == -1 && strcmp(host, "255.255.255.255") != 0) {
 	    if (interp) {
 		Tcl_ResetResult(interp);
 		Tcl_AppendResult(interp, "invalid IP address \"", 
@@ -828,3 +829,77 @@ TnmWriteMessage(interp, msg)
     }
     Tcl_DStringFree(&buffer);
 }
+
+/*
+ *----------------------------------------------------------------------
+ *
+ * TnmMkDir --
+ *
+ *	This procedure creates a path of directories. This is largely
+ *	based on the implementation of the Tcl mkdir command.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	Creates directories in the file system.
+ *
+ *----------------------------------------------------------------------
+ */
+
+int
+TnmMkDir(interp, pathname)
+    Tcl_Interp *interp;
+    char *pathname;
+{
+    Tcl_DString nameBuffer, targetBuffer;
+    int result, j, pargc;
+    char *name, **pargv;
+    struct stat statBuf;
+    
+    pargv = NULL;
+    result = TCL_OK;
+    Tcl_DStringInit(&nameBuffer);
+    Tcl_DStringInit(&targetBuffer);
+    
+    name = Tcl_TranslateFileName(interp, pathname, &nameBuffer);
+    if (name == NULL) {
+	result = TCL_ERROR;
+	goto done;
+    }
+    
+    Tcl_SplitPath(name, &pargc, &pargv);
+    if (pargc == 0) {
+	result = TCL_ERROR;
+	goto done;
+    }
+    for (j = 0; j < pargc; j++) {
+	char *target = Tcl_JoinPath(j + 1, pargv, &targetBuffer);
+	
+	/*
+	 * Call TnmStat() so that if target is a symlink that points
+	 * to a directory we will create subdirectories in that
+	 * directory.
+	 */
+
+	if (TnmStat(target, &statBuf) == 0) {
+	    if (!S_ISDIR(statBuf.st_mode)) {
+		result = TCL_ERROR;
+		goto done;
+	    }
+	} else if ((errno != ENOENT)
+		   || (TnmCreateDirectory(target) != TCL_OK)) {
+	    result = TCL_ERROR;
+	    goto done;
+	}
+	Tcl_DStringFree(&targetBuffer);
+    }
+
+ done:
+    Tcl_DStringFree(&nameBuffer);
+    Tcl_DStringFree(&targetBuffer);
+    if (pargv != NULL) {
+	ckfree((char *) pargv);
+    }
+    return result;
+}
