@@ -638,9 +638,10 @@ char *hname;
 	    }
       }
     else {
-	char tmp [512];
+	char *tmp;
 	struct hostent *hp;
-	strcpy (tmp, hname);
+
+	tmp = xstrdup(hname);
 #ifdef HAVE__RES
 	/* try to spend no longer than some seconds: */
 	_res.retrans = 1, _res.retry = 3;
@@ -650,8 +651,10 @@ char *hname;
 	      addr->sin_family = hp->h_addrtype;
 	      memcpy ((char *) &(addr->sin_addr), (char *) hp->h_addr,
 		      hp->h_length);
+	      xfree(tmp);
 	      return 1;
 	  }
+	xfree(tmp);
     }
     
     dprintf (stderr, "ntping: cannot resolve `%s'\n", hname);
