@@ -97,6 +97,7 @@
 #define AUGMENTS	146
 #define UNITS		149
 #define NUM_ENTRIES	151
+#define SIGNEDNUMBER	152
 
 #define	HASHTAB_SIZE	17			/* size of hash table */
 #define	HASH(x)		(x % HASHTAB_SIZE)	/* Hash function      */
@@ -143,8 +144,7 @@ static Keyword keywords[] =
    { "OCTET",			CONTINUE,		0 },
    { "OBJECTIDENTIFIER",	ASN1_OBJECT_IDENTIFIER,	0 },
    { "OBJECT",			CONTINUE,		0 },
-   { "BIT",			CONTINUE,		0 },
-   { "BITSTRING",		ASN1_BIT_STRING,	0 },
+   { "BITS",			ASN1_OCTET_STRING,	0 },
    { "NULL",			ASN1_NULL,		0 },
    { "SEQUENCE",		ASN1_SEQUENCE,		0 },
    { "OF",			ASN1_SEQUENCE_OF,	0 },
@@ -363,7 +363,10 @@ Tnm_MibParse(file, frozen, root)
 	tnm_MibTCSaveMark = tnm_MibTCList;
 	nodePtr = ParseFile(fp);
 	fclose(fp);
-	if (nodePtr != NULL || tnm_MibTCList != tnm_MibTCSaveMark) {
+	if (nodePtr == NULL && tnm_MibTCList == tnm_MibTCSaveMark) {
+	    unlink(frozen);
+	    return NULL;
+	} else {
 	    fp = fopen(frozen, "wb");
 	    if (fp != NULL) {
 		Tnm_MibWriteFrozen(fp, nodePtr);
@@ -505,7 +508,7 @@ ReadIntEnums(fp, strPtr)
 	if (syntax != LEFTPAREN) { fail = 1; break; }
 	/* ``{ foo ('' */
 	syntax = ReadKeyword(fp, num);
-	if (syntax != NUMBER) { fail = 1; break; }
+	if (syntax != NUMBER && syntax != SIGNEDNUMBER) { fail = 1; break; }
 	/* append to the collecting string: */
 	Tcl_DStringAppend (&result, " ", 1);
 	Tcl_DStringAppend (&result, str, -1);
@@ -1919,13 +1922,13 @@ ParseObjectType (fp, name, nodeList)
         nodePtr->tc = Tnm_MibFindTC(keyword);
 	if (nodePtr->tc) {
 	    nodePtr->syntax = nodePtr->tc->syntax;
-	}
+	} else {
+	    nodePtr->syntax = ASN1_SEQUENCE;
 #if 0
-	else {
 	    fprintf(stderr, "%s:%d: Warning: unknown syntax \"%s\"\n",
 		    tnm_MibFileName, line, keyword);
-	}
 #endif
+	}
 
 	/* 
 	 * old eat-it-up code: skip anything to the ACCESS keyword: 
@@ -2312,6 +2315,7 @@ ReadKeyword(fp, keyword)
 	     */
 	    
 	    for (cp = keyword; *cp; cp++) {
+		if (cp == keyword && (*cp == '-' || *cp == '+')) continue;
 		if (! isdigit (*cp)) return LABEL;
 	    }
 	    
@@ -2319,7 +2323,8 @@ ReadKeyword(fp, keyword)
 	     * keywords consists of digits only
 	     */
 	    
-	    return NUMBER;
+	    return (keyword[0] == '-' || keyword[0] == '+')
+		? SIGNEDNUMBER : NUMBER;
 
 	} else {
 	
