@@ -778,6 +778,11 @@ SetRequest(interp, session, request, response)
 		inVarBindPtr[i].flags |= NODE_CREATED;
 		ckfree(tmp);
 		inst = FindInstance(session, oid, oidlen);
+		if (! inst) {
+		    response->error_status = TNM_SNMP_NOCREATION;
+		    varsToRollback--;
+		    goto varBindError;
+		}
 		code = Tnm_SnmpEvalNodeBinding(session, request, inst, 
 				    TNM_SNMP_CREATE_EVENT, inVarBindPtr[i].value,
 				    (char *) NULL);
