@@ -48,7 +48,8 @@ typedef struct Message {
  */
 
 static int
-Authentic		_ANSI_ARGS_((SNMP_Session *session, Message *msg,
+Authentic		_ANSI_ARGS_((SNMP_Session *session,
+				     Message *msg, SNMP_PDU *pdu,
 				     u_char *packet, int packetlen,
 				     u_int **snmpStatPtr));
 
@@ -258,7 +259,7 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
 		*reqid = pdu->request_id;
 	    }
 
-	    if (! Authentic(session, msg, packet, packetlen, NULL)) {
+	    if (! Authentic(session, msg, pdu, packet, packetlen, NULL)) {
 		Tcl_SetResult(interp, "authentication failure", TCL_STATIC);
 		Tcl_DStringFree(&pdu->varbind);
 		return TCL_CONTINUE;
@@ -287,7 +288,7 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
 
 	    session = request->session;
 
-	    if (! Authentic(session, msg, packet, packetlen, NULL)) {
+	    if (! Authentic(session, msg, pdu, packet, packetlen, NULL)) {
 		Tcl_SetResult(interp, "authentication failure", TCL_STATIC);
 		Tcl_DStringFree(&pdu->varbind);
 		return TCL_CONTINUE;
@@ -340,10 +341,17 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
 	    }
 	    if (session->version == TNM_SNMPv1 && bindPtr && bindPtr->command
 		&& (! session->agentSocket)
-		&& Authentic(session, msg, packet, packetlen, NULL)) {
-		delivered++;
+		&& Authentic(session, msg, pdu, packet, packetlen, NULL)) {
+		char *com = session->readCommunity;
+		session->readCommunity = ckalloc(msg->comLen+1);
+		memcpy(session->readCommunity, msg->com, msg->comLen);
+		session->readCommunity[msg->comLen] = 0;
+		Tnm_SnmpEvalBinding(interp, session, pdu, TNM_SNMP_RECV_EVENT);
 		Tnm_SnmpEvalCallback(interp, session, pdu, bindPtr->command,
 				     NULL, NULL, NULL, NULL);
+		ckfree(session->readCommunity);
+		session->readCommunity = com;
+		delivered++;
 		snmpStats.snmpInTraps++;
 	    }
 	    break;
@@ -353,10 +361,25 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
 	    }
 	    if ((session->version & TNM_SNMPv2) && bindPtr && bindPtr->command
 		&& (! session->agentSocket)
-		&& Authentic(session, msg, packet, packetlen, NULL)) {
-		delivered++;
+		&& Authentic(session, msg, pdu, packet, packetlen, NULL)) {
+#ifdef TNM_SNMPv2C
+		char *com = session->readCommunity;
+		if (session->version == TNM_SNMPv2C) {
+		    session->readCommunity = ckalloc(msg->comLen+1);
+		    memcpy(session->readCommunity, msg->com, msg->comLen);
+		    session->readCommunity[msg->comLen] = 0;
+		}
+#endif
+		Tnm_SnmpEvalBinding(interp, session, pdu, TNM_SNMP_RECV_EVENT);
 		Tnm_SnmpEvalCallback(interp, session, pdu, bindPtr->command,
 				     NULL, NULL, NULL, NULL);
+#ifdef TNM_SNMPv2C
+		if (session->version == TNM_SNMPv2C) {
+		    ckfree(session->readCommunity);
+		    session->readCommunity = com;
+		}
+#endif
+		delivered++;
 		snmpStats.snmpInTraps++;
 	    }
 	    break;
@@ -365,10 +388,25 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
                 bindPtr = bindPtr->nextPtr;
             }
 	    if ((session->version & TNM_SNMPv2) && bindPtr && bindPtr->command
-                && Authentic(session, msg, packet, packetlen, NULL)) {
-                delivered++;
+                && Authentic(session, msg, pdu, packet, packetlen, NULL)) {
+#ifdef TNM_SNMPv2C
+		char *com = session->readCommunity;
+		if (session->version == TNM_SNMPv2C) {
+		    session->readCommunity = ckalloc(msg->comLen+1);
+		    memcpy(session->readCommunity, msg->com, msg->comLen);
+		    session->readCommunity[msg->comLen] = 0;
+		}
+#endif
+		Tnm_SnmpEvalBinding(interp, session, pdu, TNM_SNMP_RECV_EVENT);
                 Tnm_SnmpEvalCallback(interp, session, pdu, bindPtr->command, 
 				     NULL, NULL, NULL, NULL);
+#ifdef TNM_SNMPv2C
+		if (session->version == TNM_SNMPv2C) {
+		    ckfree(session->readCommunity);
+		    session->readCommunity = com;
+		}
+#endif
+                delivered++;
 		pdu->type = TNM_SNMP_RESPONSE;
 		if (Tnm_SnmpEncode(interp, session, pdu, NULL, NULL)
 		    != TCL_OK) {
@@ -385,7 +423,8 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
 	    {
 		u_int *statPtr;
 		if (! session->agentSocket) break;
-		if (Authentic(session, msg, packet, packetlen, &statPtr)) {
+		if (Authentic(session, msg, pdu, packet, packetlen, &statPtr)) {
+		    Tnm_SnmpEvalBinding(interp, session, pdu, TNM_SNMP_RECV_EVENT);
 		    if (Tnm_SnmpAgentRequest(interp, session, pdu) != TCL_OK) {
 			Tcl_DStringFree(&pdu->varbind);
 			return TCL_ERROR;
@@ -432,9 +471,10 @@ Tnm_SnmpDecode(interp, packet, packetlen, from, session, reqid)
  */
 
 static int
-Authentic(session, msg, packet, packetlen, snmpStatPtr)
+Authentic(session, msg, pdu, packet, packetlen, snmpStatPtr)
     SNMP_Session *session;
     Message *msg;
+    SNMP_PDU *pdu;
     u_char *packet;
     int packetlen;
     u_int **snmpStatPtr;
@@ -453,6 +493,21 @@ Authentic(session, msg, packet, packetlen, snmpStatPtr)
 #ifdef TNM_SNMPv2C
     case TNM_SNMPv2C:
 #endif
+	/*
+	 * Event reports are always considered authentic in SNMPv1 or
+	 * SNMPv2c because the community string might indicate the
+	 * context. Note, we should pass the community string to the
+	 * receiving application. I do not yet know how to do this
+	 * in a clean an elegant way.
+	 */
+	
+	if (pdu->type == TNM_SNMPv1_TRAP
+	    || pdu->type == TNM_SNMPv2_TRAP
+	    || pdu->type == TNM_SNMP_INFORM) {
+	    authentic = 1;
+	    break;
+	}
+	
 	authentic = ((strlen(community) == msg->comLen) &&
 		     (memcmp(community, msg->com, msg->comLen) == 0));
 
@@ -930,6 +985,8 @@ DecodePDU(interp, pdu, packet, packetlen)
     static int vboidLen = 0;
     char *snmpTrapEnterprise = NULL;
 
+    u_char tag;
+
     Tcl_DStringInit(&pdu->varbind);
 
     /*
@@ -1212,7 +1269,9 @@ DecodePDU(interp, pdu, packet, packetlen)
 	 * should create a type conforming null value if possible.
 	 */
 
-	switch (*packet) {
+	tag = *packet;
+
+	switch (tag) {
 	  case ASN1_NO_SUCH_OBJECT:
 	    Tcl_DStringAppendElement(&pdu->varbind, "noSuchObject");
 	    Tcl_DStringAppendElement(&pdu->varbind, 
@@ -1238,7 +1297,7 @@ DecodePDU(interp, pdu, packet, packetlen)
 	 */
 
 	{
-	    char *syntax = TnmGetTableValue(tnmSnmpTypeTable, *packet);
+	    char *syntax = TnmGetTableValue(tnmSnmpTypeTable, tag);
 	    Tcl_DStringAppendElement(&pdu->varbind, syntax ? syntax : "");
 	}
 
@@ -1246,7 +1305,7 @@ DecodePDU(interp, pdu, packet, packetlen)
 	 * decode value for object
 	 */
 
-	switch (*packet) {
+	switch (tag) {
 	  case ASN1_COUNTER32:
 	  case ASN1_GAUGE32:
             packet = Tnm_BerDecInt(packet, &pdulen, *packet, &int_val);
@@ -1332,8 +1391,9 @@ DecodePDU(interp, pdu, packet, packetlen)
 					 inet_ntoa(addr.sin_addr));
 	    }
             break;
+	  case ASN1_OPAQUE:
 	  case ASN1_OCTET_STRING:
-            packet = Tnm_BerDecOctetString(packet, &pdulen, ASN1_OCTET_STRING, 
+            packet = Tnm_BerDecOctetString(packet, &pdulen, tag, 
 					   (char **) &freeme, &int_val);
             if (packet == NULL) goto asn1Error;
 	    {   char *tmp;
@@ -1345,9 +1405,13 @@ DecodePDU(interp, pdu, packet, packetlen)
 		    hex = ckalloc(hexLen);
 		}
 		Tnm_SnmpBinToHex(freeme, int_val, hex);
-		tmp = Tnm_MibFormat(vboid, 0, hex);
-		if (tmp) {
-		    Tcl_DStringAppendElement(&pdu->varbind, tmp);
+		if (tag == ASN1_OCTET_STRING) {
+		    tmp = Tnm_MibFormat(vboid, 0, hex);
+		    if (tmp) {
+			Tcl_DStringAppendElement(&pdu->varbind, tmp);
+		    } else {
+			Tcl_DStringAppendElement(&pdu->varbind, hex);
+		    }
 		} else {
 		    Tcl_DStringAppendElement(&pdu->varbind, hex);
 		}
