@@ -801,6 +801,14 @@ EncodePDU(interp, session, pdu, packet, packetlen)
 		    asn1_type = ASN1_OTHER;
 		}
 	    }
+
+	    if (asn1_type == ASN1_OTHER) {
+		Tnm_MibTC *tcPtr;
+		tcPtr = Tnm_MibFindTC(vbv[1]);
+		if (tcPtr) {
+		    asn1_type = tcPtr->syntax;
+		}
+	    }
 	    break;
 	}
 
@@ -891,7 +899,8 @@ EncodePDU(interp, session, pdu, packet, packetlen)
 	      case ASN1_IPADDRESS:
 		{   int a, b, c, d, addr = inet_addr(value);
 		    int cnt = sscanf(value, "%d.%d.%d.%d", &a, &b, &c, &d);
-		    if (addr == -1 || cnt != 4) {
+		    if ((addr == -1 && strcmp(value, "255.255.255.255") != 0)
+			|| (cnt != 4)) {
 			Tcl_SetResult(interp, "invalid IP address", 
 				      TCL_STATIC);
 			return NULL;
@@ -927,6 +936,30 @@ EncodePDU(interp, session, pdu, packet, packetlen)
 				     ASN1_OCTET_STRING, bin, len);
 		}
 		break;
+	      case ASN1_OPAQUE:
+	        {   char *hex = value;
+		    int len;
+		    static char *bin = NULL;
+		    static int binLen = 0;
+		    if (*hex) {
+			len = strlen(hex);
+			if (binLen < len + 1) {
+			    if (bin) ckfree(bin);
+			    binLen = len + 1;
+			    bin = ckalloc(binLen);
+			}
+			if (Tnm_SnmpHexToBin(hex, bin, &len) < 0) {
+			    Tcl_SetResult(interp, "illegal Opaque value",
+					  TCL_STATIC);
+			    return NULL;
+			}
+		    } else {
+			len = 0;
+		    }
+		    packet = Tnm_BerEncOctetString(packet, packetlen,
+						   ASN1_OPAQUE, bin, len);    
+		}
+		break;
 	      case ASN1_OBJECT_IDENTIFIER:
 		if (! Tnm_IsOid(value)) {
 		    char *tmp = Tnm_MibGetOid(value, 0);
