@@ -662,9 +662,12 @@ SnmpCmd(clientData, interp, argc, argv)
     int argc;
     char **argv;
 {
+    static char mibCmd[20];
     SNMP_Session *session;
     int code;
 
+    strcpy(mibCmd, "mib oid 1.3");
+
     if (argc < 2) {
 	Tcl_AppendResult(interp, "wrong # args: should be \"", argv[0],
 			 " option ?arg arg ...?\"", (char *) NULL);
@@ -728,7 +731,7 @@ SnmpCmd(clientData, interp, argc, argv)
  	 * mechanism -- ugly but correct in most cases.
 	 */
 
-	Tcl_Eval(interp, "mib oid 1");
+	Tcl_Eval(interp, mibCmd);
 	Tcl_ResetResult(interp);
 	
 	/*
